@@ -25,7 +25,7 @@
 
 struct _SPDesktop {
 	GtkEventBox eventbox;
-	guint decorations : 1;
+	gint decorations : 1;
 	guint guides_active : 1;
 	GtkBox * table;
 	GtkScrollbar * hscrollbar;
@@ -54,12 +54,22 @@ struct _SPDesktop {
 	GnomeCanvasGroup * controls;
 	GnomeCanvasItem * page;
 	gdouble d2w[6], w2d[6];
+        gint number;
 };
 
 struct _SPDesktopClass {
 	GtkEventBoxClass parent_class;
 };
 
+#ifndef SP_DESKTOP_C
+extern gboolean SPShowFullFielName;
+#else
+gboolean SPShowFullFielName = TRUE;
+#endif
+
+
+
+
 /* Standard Gtk function */
 
 GtkType sp_desktop_get_type (void);
@@ -94,15 +104,15 @@ gint sp_desktop_set_focus (GtkWidget * widget, GtkWidget * widget2, SPDesktop *
 
 void sp_desktop_set_event_context (SPDesktop * desktop, GtkType type);
 
-#if 0
+void sp_desktop_set_title (SPDesktop * desktop);
 
-/* FIXME reimplement this somehow */
 
-void sp_desktop_set_title (const gchar * title);
+// statusbars
+void sp_desktop_default_status (SPDesktop *desktop, const gchar * text);
+void sp_desktop_set_status (SPDesktop * desktop, const gchar * stat);
+void sp_desktop_clear_status (SPDesktop * desktop);
+void sp_desktop_coordinate_status (SPDesktop * desktop, gdouble x, gdouble y, gint8 underline);
 
-#endif
-
-void sp_desktop_set_status (SPDesktop *desktop, const gchar * text);
 
 void sp_desktop_connect_item (SPDesktop * desktop, SPItem * item, GnomeCanvasItem * canvasitem);
 
